<?php

declare(strict_types=1);

namespace Monsun\Bugtest\Controller;

use Monsun\Bugtest\Domain\Repository\TestmodelRepository;
use Monsun\Bugtest\Domain\Model\Testmodel;
use Psr\Http\Message\ResponseInterface;
use TYPO3\CMS\Extbase\Persistence\Exception\IllegalObjectTypeException;
use TYPO3\CMS\Extbase\Persistence\Exception\UnknownObjectException;

/**
 * This file is part of the "routingtest" Extension for TYPO3 CMS.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * (c) 2023 Dr. Dieter Porth <porth@monun-media.com>, Monsun Media GmbH
 */

/**
 * TestmodelController
 */
class TestmodelController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController
{

    /**
     * testmodelRepository
     *
     * @var TestmodelRepository
     */
    protected $testmodelRepository = null;

    /**
     * @param TestmodelRepository $testmodelRepository
     */
    public function injectTestmodelRepository(TestmodelRepository $testmodelRepository)
    {
        $this->testmodelRepository = $testmodelRepository;
    }

    /**
     * action list
     *
     * @return ResponseInterface
     */
    public function listAction(): ResponseInterface
    {
        $testmodels = $this->testmodelRepository->findAll();
        $this->view->assign('testmodels', $testmodels);
        return $this->htmlResponse();
    }

    /**
     * action new
     *
     * @return ResponseInterface
     */
    public function newAction(): ResponseInterface
    {
        return $this->htmlResponse();
    }

    /**
     * action create
     *
     * @param Testmodel $newTestmodel
     */
    public function createAction(Testmodel $newTestmodel)
    {
        $this->addFlashMessage(
            'The object was created. Please be aware that this action is publicly accessible '.
            'unless you implement an access check. '.
            'See https://docs.typo3.org/p/friendsoftypo3/extension-builder/master/en-us/User/Index.html',
            '',
            \TYPO3\CMS\Core\Messaging\AbstractMessage::WARNING
        );
        $this->testmodelRepository->add($newTestmodel);
        $this->redirect('list');
    }

    /**
     * action edit
     *
     * @param Testmodel $testmodel
     * @TYPO3\CMS\Extbase\Annotation\IgnoreValidation("testmodel")
     *
     * @return ResponseInterface
     * @throws IllegalObjectTypeException
     * @throws UnknownObjectException
     */
    public function editAction(Testmodel $testmodel): ResponseInterface
    {
        $this->addFlashMessage(
            'The object was updated  in edit-Action. Please be aware that this action is publicly accessible '.
            'unless you implement an access check. '.
            'See https://docs.typo3.org/p/friendsoftypo3/extension-builder/master/en-us/User/Index.html',
            '',
            \TYPO3\CMS\Core\Messaging\AbstractMessage::WARNING
        );
        $this->testmodelRepository->update($testmodel);
        $this->view->assign('testmodel', $testmodel);
        return $this->htmlResponse();
    }

    /**
     * action update
     *
     * @param Testmodel $testmodel
     */
    public function updateAction(Testmodel $testmodel)
    {
        $this->addFlashMessage(
            'The object was updated in update-Action. You should never see this, because the workflow '.
            'ignore this. Please be aware that this action is publicly accessible '.
            'unless you implement an access check. '.
            'See https://docs.typo3.org/p/friendsoftypo3/extension-builder/master/en-us/User/Index.html',
            '',
            \TYPO3\CMS\Core\Messaging\AbstractMessage::WARNING
        );
        $this->testmodelRepository->update($testmodel);
        $this->redirect('list');
    }

    /**
     * action editTwo
     *
     * @return ResponseInterface
     */
    /**
     * @param Testmodel $testmodel
     * @TYPO3\CMS\Extbase\Annotation\IgnoreValidation("testmodel")
     *
     * @return ResponseInterface
     * @throws IllegalObjectTypeException
     * @throws UnknownObjectException
     */
    public function editTwoAction(Testmodel $testmodel): ResponseInterface
    {
        $this->addFlashMessage(
            'The object was updated in editTwo-Action. Please be aware that this action is publicly accessible '.
            'unless you implement an access check. '.
            'See https://docs.typo3.org/p/friendsoftypo3/extension-builder/master/en-us/User/Index.html',
            '',
            \TYPO3\CMS\Core\Messaging\AbstractMessage::WARNING
        );
        $this->testmodelRepository->update($testmodel);
        $this->view->assign('testmodel', $testmodel);
        return $this->htmlResponse();
    }

    /**
     * @param Testmodel $testmodel
     *
     * @return ResponseInterface
     */
    public function showAction(Testmodel $testmodel): ResponseInterface
    {
        $this->view->assign('testmodel', $testmodel);
        return $this->htmlResponse();
    }
}
